@@ -218,47 +218,56 @@ class EdgeFunction(
         self,
         id: builtins.str,
         *,
-        event_source_arn: builtins.str,
         batch_size: typing.Optional[jsii.Number] = None,
         bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         enabled: typing.Optional[builtins.bool] = None,
+        event_source_arn: typing.Optional[builtins.str] = None,
+        kafka_bootstrap_servers: typing.Optional[typing.List[builtins.str]] = None,
         kafka_topic: typing.Optional[builtins.str] = None,
         max_batching_window: typing.Optional[aws_cdk.core.Duration] = None,
         max_record_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IEventSourceDlq] = None,
         parallelization_factor: typing.Optional[jsii.Number] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
+        source_access_configurations: typing.Optional[typing.List[aws_cdk.aws_lambda.SourceAccessConfiguration]] = None,
         starting_position: typing.Optional[aws_cdk.aws_lambda.StartingPosition] = None,
+        tumbling_window: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> aws_cdk.aws_lambda.EventSourceMapping:
         '''(experimental) Adds an event source that maps to this AWS Lambda function.
 
         :param id: -
-        :param event_source_arn: The Amazon Resource Name (ARN) of the event source. Any record added to this stream can invoke the Lambda function.
         :param batch_size: The largest number of records that AWS Lambda will retrieve from your event source at the time of invoking your function. Your function receives an event with all the retrieved records. Valid Range: Minimum value of 1. Maximum value of 10000. Default: - Amazon Kinesis, Amazon DynamoDB, and Amazon MSK is 100 records. Both the default and maximum for Amazon SQS are 10 messages.
         :param bisect_batch_on_error: If the function returns an error, split the batch in two and retry. Default: false
         :param enabled: Set to false to disable the event source upon creation. Default: true
+        :param event_source_arn: The Amazon Resource Name (ARN) of the event source. Any record added to this stream can invoke the Lambda function. Default: - not set if using a self managed Kafka cluster, throws an error otherwise
+        :param kafka_bootstrap_servers: A list of host and port pairs that are the addresses of the Kafka brokers in a self managed "bootstrap" Kafka cluster that a Kafka client connects to initially to bootstrap itself. They are in the format ``abc.example.com:9096``. Default: - none
         :param kafka_topic: The name of the Kafka topic. Default: - no topic
         :param max_batching_window: The maximum amount of time to gather records before invoking the function. Maximum of Duration.minutes(5) Default: Duration.seconds(0)
         :param max_record_age: The maximum age of a record that Lambda sends to a function for processing. Valid Range: - Minimum value of 60 seconds - Maximum value of 7 days Default: - infinite or until the record expires.
         :param on_failure: An Amazon SQS queue or Amazon SNS topic destination for discarded records. Default: discarded records are ignored
         :param parallelization_factor: The number of batches to process from each shard concurrently. Valid Range: - Minimum value of 1 - Maximum value of 10 Default: 1
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Set to ``undefined`` if you want lambda to keep retrying infinitely or until the record expires. Valid Range: - Minimum value of 0 - Maximum value of 10000 Default: - infinite or until the record expires.
+        :param source_access_configurations: Specific settings like the authentication protocol or the VPC components to secure access to your event source. Default: - none
         :param starting_position: The position in the DynamoDB, Kinesis or MSK stream where AWS Lambda should start reading. Default: - Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources.
+        :param tumbling_window: The size of the tumbling windows to group records sent to DynamoDB or Kinesis. Default: - None
 
         :stability: experimental
         '''
         options = aws_cdk.aws_lambda.EventSourceMappingOptions(
-            event_source_arn=event_source_arn,
             batch_size=batch_size,
             bisect_batch_on_error=bisect_batch_on_error,
             enabled=enabled,
+            event_source_arn=event_source_arn,
+            kafka_bootstrap_servers=kafka_bootstrap_servers,
             kafka_topic=kafka_topic,
             max_batching_window=max_batching_window,
             max_record_age=max_record_age,
             on_failure=on_failure,
             parallelization_factor=parallelization_factor,
             retry_attempts=retry_attempts,
+            source_access_configurations=source_access_configurations,
             starting_position=starting_position,
+            tumbling_window=tumbling_window,
         )
 
         return typing.cast(aws_cdk.aws_lambda.EventSourceMapping, jsii.invoke(self, "addEventSourceMapping", [id, options]))
